Index: trunk/psLib/src/imageops/psImageConvolve.h
===================================================================
--- trunk/psLib/src/imageops/psImageConvolve.h	(revision 15320)
+++ trunk/psLib/src/imageops/psImageConvolve.h	(revision 15321)
@@ -5,6 +5,6 @@
  * @author Robert DeSonia, MHPCC
  *
- * @version $Revision: 1.30 $ $Name: not supported by cvs2svn $
- * @date $Date: 2007-10-16 23:31:03 $
+ * @version $Revision: 1.31 $ $Name: not supported by cvs2svn $
+ * @date $Date: 2007-10-17 01:49:12 $
  * Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
  */
@@ -155,22 +155,28 @@
 /// Convolve a mask image with a kernel, using direct convolution
 ///
-/// Returns a mask, grown by the supplied kernel.  Only those pixels specified by the maskVal are grown; the
-/// rest are simply propagated.
-psImage *psImageConvolveMaskDirect(const psImage *mask, ///< Mask to convolve
+/// Returns a mask, grown by the supplied convolution bounds.  Only those pixels specified by the maskVal are
+/// grown, being ORed with setVal; the rest are simply propagated.  If setVal is zero, then individual bits
+/// matching maskVal are grown.
+psImage *psImageConvolveMaskDirect(psImage *out, ///< Output image, or NULL
+                                   const psImage *mask, ///< Mask to convolve
                                    psMaskType maskVal, ///< Mask value to convolve
-                                   const psKernel *kernel ///< Kernel by which to convolve
+                                   psMaskType setVal, ///< Mask value to set; 0 to propagate maskVal
+                                   int xMin, int xMax, int yMin, int yMax ///< Convolution bounds
     );
 
 /// Convolve a mask image with a kernel, using the FFT
 ///
-/// Returns a mask, grown by the supplied kernel.  Only those pixels specified by the maskVal are grown; the
-/// rest are simply propagated.  Uses psImageConvolveFFT to convolve the mask, and then thresholds at the
-/// specified level.
-psImage *psImageConvolveMaskFFT(const psImage *mask, ///< Mask to convolve
+/// Returns a mask, grown by the supplied convolution bounds.  Only those pixels specified by the maskVal are
+/// grown, being ORed with setVal; the rest are simply propagated.  If setVal is zero, uses maskVal; note that
+/// the mode of growing individual bits in maskVal is NOT supported because this algorithm does not enable it.
+/// Uses psImageConvolveFFT to convolve those pixels which are masked, and then thresholds at the specified
+/// level.
+psImage *psImageConvolveMaskFFT(psImage *out, ///< Output image, or NULL
+                                const psImage *mask, ///< Mask to convolve
                                 psMaskType maskVal, ///< Mask value to convolve
-                                const psKernel *kernel, ///< Kernel by which to convolve
+                                psMaskType setVal, ///< Mask value to set; 0 to use maskVal
+                                int xMin, int xMax, int yMin, int yMax, ///< Convolution bounds
                                 float thresh ///< Threshold (0..1) for convolved floating-point image
     );
-
 
 /// Smooths an image by parts using 1D Gaussian independently in x and y.
